package dbrown;

import java.awt.BorderLayout;

import javax.swing.BoxLayout;
import javax.swing.JPanel;

/**
 * A GUI interface that brings together all of the sub interfaces to the Hangman
 * game. This illustrates how a model (in this case the Hangman game) can be
 * viewed by multiple interfaces at once. This view displays the buttons view,
 * the phrase view, the game control view, and the graphical view in one panel.
 *
 * @author David Brown (from Byron Weber Becker)
 * @version 2011-11-11
 */
@SuppressWarnings("serial")
public class HangmanGUI extends JPanel {
    /**
     * The sub-view containing the game control buttons.
     */
    private GameControlView gcv = null;

    /**
     * The sub-view containing the graphical representation of the hanged man.
     */
    private GallowsView gv = null;

    /**
     * The sub-view containing the buttons corresponding to the letters of the
     * alphabet.
     */
    private LettersView lv = null;

    /**
     * The sub-view containing the phrase guessed by the player so far.
     */
    private PhraseView pv = null;

    /**
     * Instantiates all of the sub-views of the Hangman game.
     *
     * @param model
     *            - the Hangman game object
     */
    public HangmanGUI(final Hangman model) {
	this.gv = new GallowsView(model);
	this.lv = new LettersView(model);
	this.pv = new PhraseView(model);
	this.gcv = new GameControlView(model);
	this.layoutView();
	// Show the current state of the model.
	// model.newGame();
    }

    /**
     * Lays out the sub-views of the Hangman game in a Border layout.
     */
    private void layoutView() {
	this.setLayout(new BorderLayout());
	this.add(this.pv, BorderLayout.SOUTH);
	this.add(this.gv, BorderLayout.CENTER);
	final JPanel buttons = new JPanel();
	buttons.setLayout(new BoxLayout(buttons, BoxLayout.Y_AXIS));
	buttons.add(this.lv);
	buttons.add(this.gcv);
	this.add(buttons, BorderLayout.EAST);
    }
}
