package dbrown;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Random;
import java.util.Scanner;

/**
 * Phrases are stored in a text file and processed by this class. Phrases may be
 * repeated within a game as they are randomly selected from the list.
 *
 * @author David Brown (from Byron Weber Becker)
 * @version 2011-11-11
 */
public class PhraseList {

    /**
     * Contains the list of phrases for the user to guess.
     */
    private final ArrayList<String> phrases = new ArrayList<>();

    /**
     * A random number generator object.
     */
    private final Random rand = new Random();

    /**
     * @param filename
     *            - the name of the text file containing the list of phrases to
     *            process
     */
    public PhraseList(final String filename) throws FileNotFoundException {

	try {
	    // Open the data file for reading.
	    final Scanner scanner = new Scanner(new File(filename));

	    // Read the contents of the data file into the list of phrases.
	    while (scanner.hasNext()) {
		this.phrases.add(scanner.nextLine().trim().toUpperCase());
	    }
	    scanner.close();
	    // The list of phrases is fixed in size, so clean it up.
	    this.phrases.trimToSize();
	} catch (final FileNotFoundException e) {
	    // Add a message to the file not found exception.
	    throw new FileNotFoundException(
		    "The file " + filename + " does not exist");
	}
    }

    /**
     * @return a random phrase from the list of phrases
     */
    public String randomPhrase() {
	final int i = this.rand.nextInt(this.phrases.size());
	return this.phrases.get(i);
    }
}
