package dbrown;

import java.awt.Font;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;

/**
 * A GUI interface to part of the Hangman game. This illustrates how a model (in
 * this case the Hangman game) can be viewed by different interfaces. This view
 * displays only the phrase as guessed by the player throughout the game and
 * displays the end of game messages.
 *
 * @author David Brown (from Byron Weber Becker)
 * @version 2011-11-11
 */
@SuppressWarnings("serial")
public class PhraseView extends JPanel {

    /**
     * Is called by the Hangman game to display the current state of the game
     * when the game is started and whenever a guess is made.
     */
    private class GameListener implements PropertyChangeListener {

	@Override
	public void propertyChange(final PropertyChangeEvent evt) {
	    // Get the phrase guessed so far from the model.
	    PhraseView.this.phrase
		    .setText(PhraseView.this.model.getGuessedPhrase());
	}
    }

    // -------------------------------------------------------------------------------

    /**
     * Displays the phrase guessed so far by the player.
     */
    private final JLabel phrase = new JLabel(" ");

    private Hangman model = null;

    /**
     * @param model
     *            - the Hangman game to be viewed
     */
    public PhraseView(final Hangman model) {
	// Layout the view and add this view to the model.
	this.model = model;
	this.layoutView();
	this.registerListeners();
    }

    /**
     * Defines the label font and positioning.
     */
    private void layoutView() {
	this.phrase.setFont(new Font("Monospaced", Font.BOLD, 24));
	this.phrase.setHorizontalAlignment(SwingConstants.CENTER);
	this.add(this.phrase);
    }

    /**
     * Adds property listeners to the model.
     */
    private void registerListeners() {
	this.model.addPropertyChangeListener(new GameListener());
    }

}
